@@ -3,8 +3,11 @@
 
 #include <R.h>
 #include <Rmath.h>
+#include <Rinternals.h>
 #include <R_ext/BLAS.h>
 #include <R_ext/Lapack.h>
+#include <R_ext/Linpack.h>
+#include <R_ext/Applic.h>
 
 /* some definitions */
 #define NULLP    (void *) 0
@@ -14,12 +17,6 @@
 #define ETA_CONV 1.0e-2
 #define repeat for(;;)
 
-/* dims functions */
-typedef enum {
-    LM,
-    LME
-} mlclass;
-
 /* dims structure */
 typedef struct DIMS_struct {
     int
@@ -29,15 +26,11 @@ typedef struct DIMS_struct {
       n,        /* number of groups (Subjects) */
       p,        /* number of fixed effects */
       q,        /* number of random effects */
+      deg,      /* degree of the B-spline */
+      ord,      /* order of penalty */
       DcRows;   /* number of rows into decomposition */
 } DIMS_struct, *DIMS;
 
-/* routines for dealing with dims objects */
-extern DIMS dims(mlclass, int *);
-extern DIMS dims_LM(int *);
-extern DIMS dims_LME(int *);
-extern void dims_free(DIMS);
-
 /* lengths and offsets structure */
 typedef struct LENGTHS_struct {
     int
@@ -49,30 +42,10 @@ typedef struct LENGTHS_struct {
       *DcOff;   /* offsets into decomposition */
 } LENGTHS_struct, *LENGTHS;
 
-/* routines for dealing with lenghts objects */
-extern LENGTHS setLengths(DIMS, int *, int *);
-extern void lengths_free(LENGTHS);
-
 /* QR structure */
 typedef struct QR_struct {
     double *mat, *qraux;
     int ldmat, nrow, ncol;
 } QR_struct, *QRStruct;
 
-/* available families */
-typedef enum {
-    NORMAL,
-    CAUCHY,
-    STUDENT,
-    SLASH,
-    CONTAMINATED
-} flclass;
-
-/* heavy tailed family structure */
-typedef struct FAMILY_struct {
-    flclass fltype; /* family type */
-    int npars;      /* number of parameters in 'family' */
-    double *nu;     /* parameter vector */
-} FAMILY_struct, *FAMILY;
-
 #endif /* HEAVY_BASE_H */
